==> sddm-0.14.0.tar.xz: sddm-0.14.0/data/translations/pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>Witaj w %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Uwaga, Caps Lock jest włączony!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Układ klawiatury</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Zaloguj</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Logowanie nie powiodło się</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Logowanie powiodło się</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Wprowadź nazwę użytkownika i hasło</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restart</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Sesja</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Wybierz użytkownika i wprowadź hasło</translation>
    </message>
</context>
</TS>

==> sddm-0.18.1.tar.xz: sddm-0.18.1/data/translations/pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation>Przytrzymaj, aby zalogować się</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation>%1 (Wayland)</translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>Uwaga, Caps Lock jest włączony!</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Układ klawiatury</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Zaloguj</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>Logowanie nie powiodło się</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>Logowanie powiodło się</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>Wprowadź nazwę użytkownika i hasło</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>Wybierz konto i wprowadź hasło</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>Sesja</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Welcome to %1</source>
        <translation>Witamy w %1</translation>
    </message>
</context>
</TS>
